### Python code to do plotting of this experiment.

import util
import numpy
from matplotlib import pyplot as pyplot

# Define gauge points, following Soares Frazao et al (2008)
offset=numpy.array([7.7,+1.8])
Gauge_xy=numpy.array([ [2.65,1.15] + offset,
                       [2.65, -0.60] + offset,
                       [4.00, 1.15] + offset,
                       [4.00,-0.8] + offset,
                       [5.20,0.3] + offset,
                       [-1.87,1.10] + offset ])

# Read model data
p2=util.get_output('urban_flow0p05.sww',0.001)
p=util.get_centroids(p2,velocity_extrapolation=True)


# Read experimental data
data_dir='/home/gareth/storage/anuga_clean/anuga_jan12/trunk/anuga_work/development/gareth/tests/urban_flow/experimental_data/Isolated_Obstacle/Isolated Obstacle/'
exp_data_h=data_dir+'building_gauges_h.txt'
exp_data_uv=data_dir+'/gareths_edits/data.txt'

# Dir to save figures
fig_dir='./figures/'
h_gauges=numpy.genfromtxt(exp_data_h, skip_header=2)
uv_gauges=numpy.genfromtxt(exp_data_uv, skip_header=2)

for i in range((Gauge_xy.shape[0])):
    Gauge=Gauge_xy[i,:]
    G_ind = ((p.x-Gauge[0])**2 + (p.y-Gauge[1])**2).argmin()

    pyplot.plot(p.time, p.stage[:,G_ind], 'o-', label='model')
    pyplot.plot(h_gauges[:,0], h_gauges[:,(i+1)],'-', label='data')
    fig_filename=fig_dir+'G'+str(i+1)+'_stage.png'
    pyplot.savefig(fig_filename)
    pyplot.legend()
    pyplot.clf()

    if(i<5):
        # Note -- Gauge 6 does not have velocity measurements
        pyplot.plot(p.time, p.xvel[:,G_ind], 'o-')
        pyplot.plot(uv_gauges[:,0], uv_gauges[:,2*i+1],'-')
        fig_filename=fig_dir+'G'+str(i+1)+'_xvel.png'
        pyplot.savefig(fig_filename)
        pyplot.clf()


        pyplot.plot(p.time, p.yvel[:,G_ind], 'o-')
        pyplot.plot(uv_gauges[:,0], uv_gauges[:,2*i+2],'-')
        fig_filename=fig_dir+'G'+str(i+1)+'_yvel.png'
        pyplot.savefig(fig_filename)
        pyplot.clf()


### Plot of experimental set-up
pyplot.figure(figsize=(8,3))
pyplot.scatter(p.x, p.y, c=p.elev>0.2,edgecolors='none', s=5.0, marker='8')
pyplot.gca().set_aspect('equal')
pyplot.xlim((4,15))
pyplot.title('Zoom of the flume geometry')
#pyplot.colorbar()
# Add gauge locations
for i in range(Gauge_xy.shape[0]):
    gauge_name='G' + str(i+1)
    pyplot.scatter(Gauge_xy[i,0], Gauge_xy[i,1],marker='x',color='white')
    pyplot.text(Gauge_xy[i,0], Gauge_xy[i,1], s=gauge_name, fontweight='black', color='white', ha='left')

pyplot.text(7.0, 1.7, 'Reservoir \n Outflow',color='white', size=8)
pyplot.quiver(7,1.5, 1.0, 0.0,color='white')
pyplot.text(4.5, 1.0, 'Reservoir',color='white')

pyplot.text(11.7, 1.5, 'Isolated \n Building',color='white',size=8)
#pyplot.quiver(12.5,1.5, -1.0, 1.0, color='white')

fig_filename=fig_dir+'Model_domain.png'
pyplot.savefig(fig_filename, orientation='landscape')
pyplot.clf()
